# wquality0


[![image](https://img.shields.io/pypi/v/wquality0.svg)](https://pypi.python.org/pypi/wquality0)
[![image](https://img.shields.io/conda/vn/conda-forge/wquality0.svg)](https://anaconda.org/conda-forge/wquality0)


**A python package for visualize water quality.**


-   Free software: MIT license
-   Documentation: https://jdavecas.github.io/wquality0
    

## Features

-   TODO
